Customer class

Represents the recipient of the invoice.

Constructors

Customer({required String name, required String address, String? phone, String? email})
const

Properties

address String
The billing address of the customer.
final
email String?
Optional contact email address.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The full name of the customer.
final
phone String?
Optional contact phone number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited