Invoice class

Main model representing a complete invoice document.

Constructors

Invoice({required InvoiceInfo info, required Supplier supplier, required Customer customer, required List<InvoiceItem> items, String currencySymbol = '\$', String? customQrPath})
const

Properties

currencySymbol String
Currency symbol to display (defaults to '$').
final
customer Customer
Information about the recipient.
final
customQrPath String?
Optional path to a custom QR code or logo image.
final
hashCode int
The hash code for this object.
no setterinherited
info InvoiceInfo
Metadata about the invoice (number, dates, etc.).
final
items List<InvoiceItem>
List of line items in the invoice.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supplier Supplier
Information about the entity issuing the invoice.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited