InvoiceInfo class

Metadata and identification for an invoice.

Constructors

InvoiceInfo({required String description, required String number, required DateTime date, required DateTime dueDate})
const

Properties

date DateTime
The date the invoice was issued.
final
description String
A brief summary or terms of the invoice.
final
dueDate DateTime
The date by which payment is expected.
final
hashCode int
The hash code for this object.
no setterinherited
number String
Unique identifier or serial number for the invoice.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited