Supplier class
Represents the company or individual issuing the invoice.
Constructors
Properties
- address → String
-
The business address of the supplier.
final
- email → String?
-
Optional contact email address.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The business name of the supplier.
final
- paymentInfo → String
-
Payment instructions (e.g., bank account, PayPal).
final
- phone → String?
-
Optional contact phone number.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- website → String?
-
Optional business website URL.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited