PDFDoc class

Properties

hashCode int
The hash code for this object.
no setterinherited
info PDFDocInfo
no setter
length int
no setter
password String
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text Future<String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pageAt(int index) PDFPage
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPath(String path, {String password = ""}) Future<PDFDoc>