InvoiceItem class

Represents a single line item in an invoice.

Constructors

InvoiceItem({required String description, required DateTime date, required int quantity, required double vat, required double unitPrice})
const

Properties

date DateTime
Date associated with the line item.
final
description String
Name or description of the product/service.
final
hashCode int
The hash code for this object.
no setterinherited
quantity int
Number of units.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unitPrice double
Price per single unit.
final
vat double
Value Added Tax rate (e.g., 0.15 for 15%).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited