PDFDocInfo class
Properties
-
final
- creationDate → DateTime?
-
final
- creator → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keywords
→ List<
String> -
final
- modificationDate → DateTime?
-
final
- producer → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String?
-
final
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited